elephant.parallel.MPICommExecutor
=================================

.. currentmodule:: elephant.parallel

.. autoclass:: MPICommExecutor
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MPICommExecutor.__init__
      ~MPICommExecutor.execute
   
   

   
   
   